/**
Module Directives as public properties
this.title 				= "Title of the module";
this.author 			= "Author of the module";
this.webURL 			= "Web URL for docs purposes";
this.description 		= "Module description";
this.version 			= "Module Version";
this.viewParentLookup   = (true) [boolean] (Optional) // If true, checks for views in the parent first, then it the module.If false, then modules first, then parent.
this.layoutParentLookup = (true) [boolean] (Optional) // If true, checks for layouts in the parent first, then it the module.If false, then modules first, then parent.
this.entryPoint  		= "" (Optional) // If set, this is the default event (ex:forgebox:manager.index) or default route (/forgebox) the framework
									       will use to create an entry link to the module. Similar to a default event.
this.cfmapping			= "The CF mapping to create";
this.modelNamespace		= "The namespace to use for registered models, if blank it uses the name of the module."
this.dependencies 		= "The array of dependencies for this module"

structures to create for configuration
- parentSettings : struct (will append and override parent)
- settings : struct
- interceptorSettings : struct of the following keys ATM
	- customInterceptionPoints : string list of custom interception points
- interceptors : array
- layoutSettings : struct (will allow to define a defaultLayout for the module)
- routes : array Allowed keys are same as the addRoute() method of the SES interceptor.
- wirebox : The wirebox DSL to load and use

Available objects in variable scope
- controller
- appMapping (application mapping)
- moduleMapping (include,cf path)
- modulePath (absolute path)
- log (A pre-configured logBox logger object for this object)
- binder (The wirebox configuration binder)
- wirebox (The wirebox injector)

Required Methods
- configure() : The method ColdBox calls to configure the module.

Optional Methods
- onLoad() 		: If found, it is fired once the module is fully loaded
- onUnload() 	: If found, it is fired once the module is unloaded

*/
component {

	// Module Properties
	this.title 				= "bugsnag";
	this.author 			= "";
	this.webURL 			= "";
	this.description 		= "";
	this.version			= "0.3.0";
	// If true, looks for views in the parent first, if not found, then in the module. Else vice-versa
	this.viewParentLookup 	= true;
	// If true, looks for layouts in the parent first, if not found, then in module. Else vice-versa
	this.layoutParentLookup = true;
	// Module Entry Point
	this.entryPoint			= "bugsnag";
	// Inherit Entry Point
	this.inheritEntryPoint 	= false;
	// Model Namespace
	this.modelNamespace		= "bugsnag";
	// CF Mapping
	this.cfmapping			= "bugsnag";
	// Auto-map models
	this.autoMapModels		= true;
	// Module Dependencies
	this.dependencies 		= [];

	function configure(){
		// module settings - stored in modules.name.settings
		settings = {
			"ApiKey": "",
			// is this app in development, staging, or production?
			"releaseStage": "development",
			// only notify for these environments
			"notifyReleaseStages": ["development","staging","production"],
		    // Enable the BugSnag LogBox Appender Bridge
			"enableLogBoxAppender" = true,
		    // Min/Max levels for appender
		    "levelMin" = "FATAL",
		    "levelMax" = "INFO",
			// Enable/disable error logging
			"enableExceptionLogging" = true,
		    // Data sanitization, scrub fields and headers, replaced with * at runtime
		    "scrubFields" 	= [ "passwd", "password", "password_confirmation", "secret", "confirm_password", "secret_token", "APIToken", "x-api-token" ],
			"scrubHeaders" = [ "x-api-token", "Authorization" ]
		};

		// // SES Routes
		// routes = [
		// 	// Module Entry Point
		// 	{ pattern="/", handler="home", action="index" },
		// 	// Convention Route
		// 	{ pattern="/:handler/:action?" }
		// ];

	}

	/**
	 * Capture runtime and compilation errors and send them to Bugsnag.
	 *
	 * @event 
	 * @interceptData 
	 * @buffer 
	 */
	function onException( event, interceptData, buffer ){
		if( !settings.enableExceptionLogging ){
			return;
		}
		var bugsnagService = wirebox.getInstance("BugsnagService@bugsnag");
		bugsnagService.sendException(
			exception = interceptData.exception,
			level 	= "error"
		);
	}

	/**
	* Fired when the module is registered and activated
	* and the settings have been overriden from the "parent"
	* (coldbox config or commandbox config)
	*/
	function postModuleLoad(){
		// Load the LogBox Appenders
		if( settings.enableLogBoxAppender ){
			loadAppenders();
		}
	}

	/**
	* Fired when the module is unregistered and unloaded
	*/
	function onUnload(){

	}

	//**************************************** PRIVATE ************************************************//	

	// load LogBox appenders
	private function loadAppenders(){
		// Get config
		var logBoxConfig 	= logbox.getConfig();
		var rootConfig 		= "";

		// Register tracer appender
		rootConfig = logBoxConfig.getRoot();
		logBoxConfig.appender( 
			name 		= "bugsnag_appender", 
			class 		= "#moduleMapping#.models.BugsnagAppender",
			levelMin 	= settings.levelMin,
			levelMax 	= settings.levelMax
		);
		logBoxConfig.root( 
			levelMin = rootConfig.levelMin,
			levelMax = rootConfig.levelMax,
			appenders= listAppend( rootConfig.appenders, "bugsnag_appender") 
		);

		// Store back config
		logbox.setConfig( logBoxConfig );
	}
}